<?php
/**
 * Function file - businest - Default Function
 * 
 * 
 * @version businest 1.5.0
 **/

# Theme Setup

define( 'THEME_VERSION', '1.11.0' );

add_action('after_setup_theme', 'businest_setup');
function businest_setup()
{
    add_theme_support( 'custom-logo' );
	add_theme_support('automatic-feed-links');
	add_theme_support('post-thumbnails');
	add_theme_support('title-tag');
	add_theme_support( 'woocommerce' );
    add_theme_support( 'bbpress' );

    register_nav_menus(
        array(
        'primary' => esc_html__('Primary Menu', 'businest'),
        )
    );
    add_theme_support( 'custom-header', array(
        'width'       => 1080,
        'height'      => 190,
        'flex-height' => true,
        'flex-width' => true,
    ) );
    add_image_size( 'img_348_201', 348, 201, true );

    $args = array();
    $lpos = esc_html(get_theme_mod( 'display_logo_and_title' ));
    if ( false === $lpos || 'image' == $lpos ) {
        $args['header-text'] = array( 'blog-name' );
    }
    add_theme_support( 'custom-logo', $args );


    add_theme_support('editor-styles');
    add_editor_style('style-editor.css');

}

# Enqueue Scripts
add_action( 'wp_enqueue_scripts', 'businest_load_scripts' );
function businest_load_scripts()
{
	wp_enqueue_style( 'businest-style', get_stylesheet_uri(), array(), '' );
	wp_style_add_data( 'businest-style', 'rtl', 'replace' );
	
	# CSS
	wp_enqueue_style('bootstrap_css', get_template_directory_uri().'/assets/css/bootstrap.min.css', array(), true );
	wp_enqueue_style('fontawesome_css', get_template_directory_uri().'/assets/css/font-awesome.min.css', array(), true );
	wp_enqueue_style('businest-main-style', get_template_directory_uri() . '/style.css',  array(), '1.11.0');
    wp_enqueue_style('businest-custom-style', get_template_directory_uri() . '/assets/css/custom-style.css',  array(), '1.11.0');
    

    # JS
	wp_enqueue_script( 'bootstrap_js', get_template_directory_uri() . '/assets/js/bootstrap.bundle.min.js', array( 'jquery' ), true, true );
	wp_localize_script( 'businest-scripts', 'businest', array(
        'ajaxurl' => esc_url( admin_url('admin-ajax.php') )
    ));
    
    if ( is_singular() && get_option('thread_comments') ) {
        wp_enqueue_script('comment-reply');
    }
}


# Set businest Content Width
if ( ! isset( $content_width ) ) { $content_width = 1170; }


/* -------------------------------------------------- */
function businest_stringModify($string, $start, $limit) {
	$str = trim(strip_tags($string));
	if($limit) {
		$str = trim(substr($str, $start, $limit));
		if(strlen($string)>$limit)
			$str .= '...';
	}
	return $str;
}

# businest Pagination
function businest_pagination()
{
    if ( get_the_posts_pagination() ) : ?>
    <div class="businest-pagination"><?php
        $args = array(
            'prev_text' => '<span class="fa fa-angle-left"></span>',
            'next_text' => '<span class="fa fa-angle-right"></span>'
        );
        the_posts_pagination($args);
    ?>
    </div>
    <?php
    endif;
}

# businest Register Sidebar
add_action( 'widgets_init', 'businest_widgets_init' );
function businest_widgets_init() {
    register_sidebar(array(
		'name'            => esc_html__('Primary Sidebar', 'businest'),
		'id'              => 'sidebar',
		'before_widget'   => '<div id="%1$s" class="widget %2$s">',
		'after_widget'    => '</div>',
		'before_title'    => '<h4 class="widget-title">',
		'after_title'     => '</h4>'
	));
}

# Language 
load_theme_textdomain( 'businest', get_template_directory() . '/languages' );
/* -------------------------------------------------- */

require_once get_template_directory() . '/inc/bs4navwalker.php';

function businest_excerpt($limit) {
	$excerpt = explode(' ', get_the_excerpt(), $limit);
	if (count($excerpt)>=$limit) {
		array_pop($excerpt);
		$excerpt = implode(" ",$excerpt).'...';
	} else {
		$excerpt = implode(" ",$excerpt);
	}
	$excerpt = preg_replace('`[[^]]*]`','',$excerpt);
	return $excerpt;
}

if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
	add_filter( 'woocommerce_add_to_cart_fragments', 'businest_cart_count_fragments', 10, 1 );
	add_action( 'wp_head', 'businest_cart_count_styles' );
	add_filter( 'wp_nav_menu_main-menu_items', 'businest_cart_icon', 10, 2 );
	function businest_cart_count_fragments( $fragments ) {
	    $fragments['li.cart'] = '<li class="cart menu-item menu-item-type-post_type menu-item-object-page"><a href="' . get_permalink( wc_get_page_id( 'cart' ) ) . '"><i class="fa fa-shopping-cart"></i><span class="count">'.WC()->cart->get_cart_contents_count().'</span></a></li>';
	    return $fragments;
	}
	function businest_cart_count_styles() {
	    ?>
	    <style>
	        ul.businest-nav .cart { position: relative; }
	        ul.businest-nav .cart .fa{ font-size: 18px;}
	        ul.businest-nav .count { background: #2ea3f2; font-size: 12px; color: #fff; border-radius: 2em; height: 18px; line-height: 18px; position: absolute; right: 20px; text-align: center; top: 45%; transform: translateY(-100%) translateX(15%); width: 18px; }
	    </style>
	    <?php
	}
	function businest_cart_icon( $items, $args ) {
	    $cart_item_count = WC()->cart->get_cart_contents_count();
	    $cart_count_span = '';
	    if ( $cart_item_count ) {
	        $cart_count_span = '<span class="count">'.$cart_item_count.'</span>';
	    }
	    $cart_link = '<li class="cart menu-item menu-item-type-post_type menu-item-object-page"><a href="' . get_permalink( wc_get_page_id( 'cart' ) ) . '"><i class="fa fa-shopping-cart"></i>'.$cart_count_span.'</a></li>';
	    // Add the cart link to the end of the menu.
	    $items = $items . $cart_link;
	    return $items;
	}
}

add_action('woocommerce_before_main_content', 'businest_wrapper_start', 10);
add_action('woocommerce_after_main_content', 'businest_wrapper_end', 10);
function businest_wrapper_start() {
    echo '<div class="container mt-5">';
}
function businest_wrapper_end() {
    echo '</div>';
}

function businest_remove_sidebar( $is_active_sidebar, $index ) {              
    if( $index !== "sidebar" ) {
        return $is_active_sidebar;
    }
    if( ! is_product() ) {
        return $is_active_sidebar;
    }
    return false;
}
add_filter( 'is_active_sidebar', 'businest_remove_sidebar', 10, 2 );


if ( is_admin() ) {
	require get_template_directory() . '/includes/admin/class-hvthemes-admin.php';
	require get_template_directory() . '/includes/admin/class-hvthemes-dashboard.php';
	require get_template_directory() . '/includes/admin/class-hvthemes-notice.php';
	require get_template_directory() . '/includes/admin/class-hvthemes-welcome-notice.php';
	require get_template_directory() . '/includes/admin/class-hvthemes-upgrade-notice.php';
	require get_template_directory() . '/includes/admin/class-hvthemes-theme-review-notice.php';
}

